@@ -264,7 +264,7 @@ prepare_dm_for_flatten <- function(dm, tables, gotta_rename) {
   # renaming will be minimized if we reduce the `dm` to the necessary tables here
   red_dm <-
     dm_reset_all_filters(dm) %>%
-    dm_select_tbl(tables)
+    dm_select_tbl(!!!tables)
   # Only need to compute `tbl(dm, start)`, `dm_apply_filters()` not necessary
   # Need to use `dm` and not `clean_dm` here, because of possible filter conditions.
   start_tbl <- dm_get_filtered_table(dm, start)
