@@ -58,12 +58,14 @@ utils::globalVariables(c(
   "remote_name",
   "renames",
   "schema",
+  "schema_name",
   "source_name",
   "sub_text",
   "t1",
   "t1_name",
   "t2",
   "t2_name",
+  "table_name",
   "tbl_name",
   "tbls",
   "text",
