@@ -42,7 +42,7 @@ test_that("auto-renaming works", {
   expect_equivalent_dm(
     expect_name_repair_message(
       dm_bind(dm_for_filter(), dm_for_flatten(), dm_for_filter(), repair = "unique")
-      ),
+    ),
     bind_rows(
       dm_get_def(
         dm_rename_tbl(
@@ -52,7 +52,9 @@ test_that("auto-renaming works", {
           tf_3...3 = tf_3,
           tf_4...4 = tf_4,
           tf_5...5 = tf_5,
-          tf_6...6 = tf_6)),
+          tf_6...6 = tf_6
+        )
+      ),
       dm_get_def(dm_for_flatten()),
       dm_get_def(dm_rename_tbl(
         dm_for_filter(),
@@ -61,8 +63,9 @@ test_that("auto-renaming works", {
         tf_3...14 = tf_3,
         tf_4...15 = tf_4,
         tf_5...16 = tf_5,
-        tf_6...17 = tf_6))
-      ) %>%
+        tf_6...17 = tf_6
+      ))
+    ) %>%
       new_dm3()
   )
 
