@@ -59,6 +59,15 @@ test_that("output", {
     abort_only_for_local_src(mtcars)
     abort_parameter_not_correct_class("number", correct_class = "numeric", class = "logical")
     abort_parameter_not_correct_length("length_1_parameter", 1, letters[1:26])
-    warn_if_not_null("NULL", "dbms_dependent_arg")
+    warn_if_arg_not("NULL", "dbms_dependent_arg")
+    abort_schema_exists("silhouette")
+    abort_schema_exists("silhouette", "exhibition")
+    abort_no_schema_exists("table_1")
+    abort_no_schema_exists("fastfood", "gala_dinner")
+    abort_no_schemas_supported("FantasticDatabaseManagementSystem", "hyperconnection")
+    abort_no_schemas_supported(con = 1)
+    abort_no_schemas_supported()
+    abort_temporary_not_in_schema()
+    abort_one_of_schema_table_names()
   })
 })
